==> jc-1.4.0.tar.gz: soot/javaToJimple/SaveASTVisitor.h <==
// public class soot.javaToJimple.SaveASTVisitor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 8d4183ae5e6632c0 soot_javaToJimple_SaveASTVisitor

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_soot_javaToJimple_SaveASTVisitor_H_
#define _JC_soot_javaToJimple_SaveASTVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$sub_refs	_jc_soot_javaToJimple_SaveASTVisitor$sub_refs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs	_jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$refs	_jc_soot_javaToJimple_SaveASTVisitor$refs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$nonrefs	_jc_soot_javaToJimple_SaveASTVisitor$nonrefs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$object	_jc_soot_javaToJimple_SaveASTVisitor$object;

typedef const struct _jc_soot_javaToJimple_SaveASTVisitor$vmethods	_jc_soot_javaToJimple_SaveASTVisitor$vmethods;
typedef const struct _jc_soot_javaToJimple_SaveASTVisitor$vtable	_jc_soot_javaToJimple_SaveASTVisitor$vtable;
typedef const struct _jc_soot_javaToJimple_SaveASTVisitor$vtype	_jc_soot_javaToJimple_SaveASTVisitor$vtype;

// Constructors
extern void _jc_soot_javaToJimple_SaveASTVisitor$method$_init$72eaee106039c8e0(_jc_env *, struct _jc_soot_javaToJimple_SaveASTVisitor$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_javaToJimple_SaveASTVisitor$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_soot_javaToJimple_SaveASTVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_SaveASTVisitor$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_soot_javaToJimple_SaveASTVisitor$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_soot_javaToJimple_SaveASTVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_SaveASTVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_soot_javaToJimple_SaveASTVisitor$vmethods	soot_javaToJimple_SaveASTVisitor;
};

// Vtype
struct _jc_soot_javaToJimple_SaveASTVisitor$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_SaveASTVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_SaveASTVisitor$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_object	*extInfo;
	struct _jc_java_util_HashMap$object	*sourceJobMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_SaveASTVisitor$refs {
    _jc_soot_javaToJimple_SaveASTVisitor$sub_refs	soot_javaToJimple_SaveASTVisitor;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_SaveASTVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs	soot_javaToJimple_SaveASTVisitor;
};

// Object instance structure
struct _jc_soot_javaToJimple_SaveASTVisitor$object {
	_jc_soot_javaToJimple_SaveASTVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_SaveASTVisitor$vtype	*vtype;
	_jc_soot_javaToJimple_SaveASTVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_SaveASTVisitor$vtype _jc_soot_javaToJimple_SaveASTVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_SaveASTVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_SaveASTVisitor$class_object;

#endif	/* _JC_soot_javaToJimple_SaveASTVisitor_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/SaveASTVisitor.h <==
// public class soot.javaToJimple.SaveASTVisitor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 8d4183ae5e6632c0 soot_javaToJimple_SaveASTVisitor

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_soot_javaToJimple_SaveASTVisitor_H_
#define _JC_soot_javaToJimple_SaveASTVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$sub_refs	_jc_soot_javaToJimple_SaveASTVisitor$sub_refs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs	_jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$refs	_jc_soot_javaToJimple_SaveASTVisitor$refs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$nonrefs	_jc_soot_javaToJimple_SaveASTVisitor$nonrefs;
typedef struct _jc_soot_javaToJimple_SaveASTVisitor$object	_jc_soot_javaToJimple_SaveASTVisitor$object;

typedef const struct _jc_soot_javaToJimple_SaveASTVisitor$vmethods	_jc_soot_javaToJimple_SaveASTVisitor$vmethods;
typedef const struct _jc_soot_javaToJimple_SaveASTVisitor$vtable	_jc_soot_javaToJimple_SaveASTVisitor$vtable;
typedef const struct _jc_soot_javaToJimple_SaveASTVisitor$vtype	_jc_soot_javaToJimple_SaveASTVisitor$vtype;

// Constructors
extern void _jc_soot_javaToJimple_SaveASTVisitor$method$_init$72eaee106039c8e0(_jc_env *, struct _jc_soot_javaToJimple_SaveASTVisitor$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_javaToJimple_SaveASTVisitor$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_soot_javaToJimple_SaveASTVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_SaveASTVisitor$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_soot_javaToJimple_SaveASTVisitor$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_soot_javaToJimple_SaveASTVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_SaveASTVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_soot_javaToJimple_SaveASTVisitor$vmethods	soot_javaToJimple_SaveASTVisitor;
};

// Vtype
struct _jc_soot_javaToJimple_SaveASTVisitor$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_SaveASTVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_SaveASTVisitor$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_object	*extInfo;
	struct _jc_java_util_HashMap$object	*sourceJobMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_SaveASTVisitor$refs {
    _jc_soot_javaToJimple_SaveASTVisitor$sub_refs	soot_javaToJimple_SaveASTVisitor;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_SaveASTVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_soot_javaToJimple_SaveASTVisitor$sub_nonrefs	soot_javaToJimple_SaveASTVisitor;
};

// Object instance structure
struct _jc_soot_javaToJimple_SaveASTVisitor$object {
	_jc_soot_javaToJimple_SaveASTVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_SaveASTVisitor$vtype	*vtype;
	_jc_soot_javaToJimple_SaveASTVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_SaveASTVisitor$vtype _jc_soot_javaToJimple_SaveASTVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_SaveASTVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_SaveASTVisitor$class_object;

#endif	/* _JC_soot_javaToJimple_SaveASTVisitor_H_ */
